﻿<?php
$___notjson=1;
/**
 * Die Klasse der Arbeit mit Loginza API (http://loginza.ru/api-overview).
 * 
 * Diese Klasse ist ein Beispiel, das man einfach wie es ist nutzen kann, 
 * oder in eigenem Code nutzen oder diese Version für sich ändern.
 * 
 * PHP 5 ist notwendig, sowie CURL oder Erlaubnis mit Ressourcen http:// für file_get_contents zu arbeiten.
 * 
 * @link http://loginza.ru/api-overview
 * @author Sergey Arsenichev, PRO-Technologies Ltd.
 * @version 1.0
 */
class LoginzaAPI {
	/**
	 * Version der Klasse
	 *
	 */
	const VERSION = '1.0';
	/**
	 * URL für Zusammenarbeit mit API loginza
	 *
	 */
	const API_URL = 'http://loginza.ru/api/%method%';
	/**
	 * URL des Widgets Loginza
	 *
	 */
	const WIDGET_URL = 'https://loginza.ru/api/widget';
	
	/**
	 * Information des Profils des eingeloggten Benutzers bekommen
	 *
	 * @param string $token Token Schlüssel des eingeloggten Benutzers
	 * @return mixed
	 */
	public function getAuthInfo ($token) {
		return $this->apiRequert('authinfo', array('token' => $token));
	}
	
	/**
	 * Bekommt die Adresse des Links des Widgets Loginza
	 *
	 * @param string $return_url Link des Rückgangs, wohin der Benutzer nach Einloggen zurückgesendet wird
	 * @param string $provider Anbieter als Standard von der Liste: google, yandex, mailru, vkontakte, facebook, twitter, loginza, myopenid, webmoney, rambler, mailruapi:, flickr, verisign, aol
	 * @param string $overlay Typ des Einbaus des Widgets: true, wp_plugin, loginza
	 * @return string
	 */
	public function getWidgetUrl ($return_url=null, $provider=null, $overlay='') {
		$params = array();
		
		if (!$return_url) {
			$params['token_url'] = $this->currentUrl();
		} else {
			$params['token_url'] = $return_url;
		}
		
		if ($provider) {
			$params['provider'] = $provider;
		}
		
		if ($overlay) {
			$params['overlay'] = $overlay;
		}
		
		return self::WIDGET_URL.'?'.http_build_query($params);
	}
	
	/**
	 * Gibt den Link auf die laufende Seite zurück
	 *
	 * @return string
	 */
	private function currentUrl () {
		$url = array();
		// Prüfung https
		if(isset($_SERVER['HTTPS']) && $_SERVER['HTTPS']=='on') {
			$url['sheme'] = "https";
			$url['port'] = '443';
		} else {
			$url['sheme'] = 'http';
			$url['port'] = '80';
		}
		// Host
		$url['host'] = $_SERVER['HTTP_HOST'];
		// wenn der Port nicht standartisiert ist
		if (strpos($url['host'], ':') === false && $_SERVER['SERVER_PORT'] != $url['port']) {
			$url['host'] .= ':'.$_SERVER['SERVER_PORT'];
		}
		// Zeile der Anfrage
		if (isset($_SERVER['REQUEST_URI'])) {
			$url['request'] = $_SERVER['REQUEST_URI'];
		} else {
			$url['request'] = $_SERVER['SCRIPT_NAME'] . $_SERVER['PATH_INFO'];
			$query = $_SERVER['QUERY_STRING'];
			if (isset($query)) {
			  $url['request'] .= '?'.$query;
			}
		}
		
		return $url['sheme'].'://'.$url['host'].'/php/loginza/example.php';
	}
	
	/**
	 * Macht die Anfrage für API loginza
	 *
	 * @param string $method
	 * @param array $params
	 * @return string
	 */
	private function apiRequert($method, $params) {
		// url Anfrage
		$url = str_replace('%method%', $method, self::API_URL).'?'.http_build_query($params);
		
		if ( function_exists('curl_init') ) {
			$curl = curl_init($url);
			$user_agent = 'LoginzaAPI'.self::VERSION.'/php'.phpversion();
			
			curl_setopt($curl, CURLOPT_RETURNTRANSFER, true);
			curl_setopt($curl, CURLOPT_HEADER, false);
			curl_setopt($curl, CURLOPT_USERAGENT, $user_agent);
			curl_setopt($curl, CURLOPT_SSL_VERIFYPEER, false);
			$raw_data = curl_exec($curl);
			curl_close($curl);
			$responce = $raw_data;
		} else {
			$responce = file_get_contents($url);
		}
		
		// Bearbeitung der JSON Antwort API
		return $this->decodeJSON($responce);
	}
	
	/**
	 * Bearbeiten JSON Daten
	 *
	 * @param string $data
	 * @return object
	 */
	private function decodeJSON ($data) {
		if ( function_exists('json_decode') ) {
			return json_decode ($data);
		}
		
		// laden wir die Bibliothek der Arbeit mit JSON hoch, wenn sie notwendig ist
		if (!class_exists('Services_JSON')) {
			require_once( dirname( __FILE__ ) . '/JSON.php' );
		}
		
		$json = new Services_JSON();	
		return $json->decode($data);
	}
	
	public function debugPrint ($responceData, $recursive=false) {
			echo '<hr>Bezeichner: '.$responceData->identity.'<br>';
			echo 'Geschlecht: '.$responceData->gender.'<br>';
			echo 'Geburtstag: '.$responceData->dob.'<br>';
			echo 'Avatar: '.$responceData->photo.'<br>';
			echo 'Land: '.$responceData->address->home->country.' ('.$responceData->language.')<br>';
			echo 'Staat: '.$responceData->address->home->state.'<br>';
			echo 'E-Mail: '.$responceData->email.'<br>';
			echo 'Webseite: '.$responceData->web->default.'<hr><br>';
			print('<pre>');
			print_r($responceData);
			print('</pre>');
	}
}

?>